;--------------------------------------
; Author: Amin Boroomand
; version 3.0
; Last update: 05/1/2022
; credit:The base of this code is by joshua becker
; Expansions: Agents change more than 1 bit at a time (Risk-taking and Hardworking agents)
; Expansions: Superiority Bias, Communication noise
;--------------------------------------

;;;;; 1: DEFINITIONS
;1.1 Defining variables
extensions[array palette]
globals
[
  nk-space         ;  an array of length b^(K+1) that determines the value of a given allele. b in this case is equal to 2 since solutions are binary strings.
  allele-map       ; an array of length N that maps each digit-location to K-1 other digit-locations.
  infinity         ; A very large number, used to denote distance between two turtles which. Don't have a connected or unconnected path between them
  b                ; b is equal to 2 since solutions consist of binary numbers
  global-max
  global-min
  plist            ;; used for value distribution. It make a list of 8 random digits less than one like [0.2, 0.34, 0, 0.2353, 0.94543, 0.234, 0.5654, 0.565]
                   ;  We use plist to make a list of numbers less than 1000 to creat nk-distribution from a uniform distribution
  numpeaks         ;;  numpeaks set the number of digits in plist. in this case it is 8

  solution_list    ;; List of all solutions evaluated in the simulation
  cost             ;; Exploration cost
  ;c_error          ;; copying error for exploitation
  sol_list_test


  ;----------------------
  ; Variables for the small world networks ; only in Small word networks
  clustering-coefficient               ; Clustering coefficient of the network or average of clustering coefficients of all turtles
  average-path-length                  ; average path length of the network
  clustering-coefficient-of-lattice    ; the clustering coefficient of the initial lattice
  average-path-length-of-lattice       ; average path length of the initial lattice
  number-rewired                       ; number of edges that have been rewired. used for plots.
  rewire-one?                          ; these two variables record which button was last pushed
  rewire-all?

  ; Variables for random assignment of type of agents in a mix list. Only for mix teams of different types of agents (Hardworking, Risk-taking)
  variable
  hardworking_list  ;list of who numbers of hardworking agents in mixed population
  RiskTaking_list   ;list of who numbers of risk_taking agents in mixed population
  guarantee_list    ;list of elements in a solution that we guanrantee the copy accuratly in exploitation with error
  terminate
]

; 1.2 Defining agents and its properties
turtles-own
[
  Agentt_type                   ;; types of agents including HW, RT, hybrid
  solution                      ;; a turtle's solution to the complex problem.
  solution_value
  distance-from-other-turtles   ;; list of distances of this node from other turtles so small-world rewiring doesn't leave islands
  node-clustering-coefficient   ;; Variable for the small world network
  Self_superiority_perception ; The perception error of an agent when he see himself better than what he really is
  Others_superiority_perception ; The perception error of an agent when he see others better that what they really are
]

links-own
[
  rewired?
]

;;;;; 2: INITIATION
; Function 1: Set up
to setup
  set terminate 0
  clear-all
  ask patches [ set pcolor white ]
  set infinity 99999  ;; just an arbitrary choice for a large number
  set b 2
  set cost 0
  set solution_list []
  set sol_list_test []
  ;; initialize distribution
  set numpeaks 8
  set plist []
  let i 0
  while [i < numpeaks]
  [
    set plist lput random-float 1 plist   ; it make a list of 8 random digits less than one like [0.2, 0.34, 0, 0.2353, 0.94543, 0.234, 0.5654, 0.565]
    set i i + 1
  ]

  ; Assign values to the allele vectors
  define-allele-values

  set-interdependencies    ;it makes the allele map. which other (k-1) digits in N are associaited with a certain digit
  ; Define the agents
  spawn-turtles


  ; define the neighbors between agents in network
  wire-ringlat

  ;;;;making list of random numbers to use for mix population. A mix population is a population with different types of agents (HW, RT);;;;;;;
  ;;;Here we create two lists of random numbers for hardworking and risktaking. We use those numbers as who number to assign turtules types;;;
  if Mix_team
  [
    if HW_num + RT_num > number-of-agents
    [ show "Error!  sum of HW and RT cannot be bigger than the totall number of agents."
    ]
    set  hardworking_list [] ; a random list to use as who number to assign which agent should behave as hardworking
    let s 0
  while [s < HW_num]
    [
    let number random number-of-agents
    if (not member? number hardworking_list)
      [
       set hardworking_list lput number  hardworking_list
      set s  s + 1
      ]
    ]
  set  RiskTaking_list []  ;; a random list to use as who number to assign which agent should behave as Risktaking
  let p 0
  while [p < RT_num]
    [
    let numbers random number-of-agents
    if (not member? numbers hardworking_list)
      [
       if (not member? numbers RiskTaking_list)
        [
         set RiskTaking_list lput numbers  RiskTaking_list
        set p  p + 1
        ]
      ]
    ]
   ]
  reset-ticks
end

; Function 2: Go
to go
  run-step                                        ;The logic of model start from here
  ;This part is to stop the simulation when all agents reach the global maximum or team reach 200 time-steps
  ;let compare-to [solution] of turtle 0
  if
  average-score = 1.0
  [
   set terminate terminate + 1                        ;If any agent's solution was similar to the solution of agents 0 then we stop
  ]
  if terminate > 1
  [
    stop
  ]


  if ticks >= 200                                    ; Condition to limit the total number of time units to prevent infinite loops
  [
    stop
  ]
end

; Function 3: run a step: This is called when the Set up key on the interface is clickded
to run-step
  set solution_list []
  set sol_list_test []
  ask turtles
  [
    set Agentt_type Agent_type    ; setting the agent types (Hardworking, risk-taking)
    if Mix_team
    [
      set Agentt_type "Normal"
      foreach hardworking_list                     ;assigning hardwoking or risk taking type to agents in mix teams
      [
        x -> (if who = x [set Agentt_type "hard_worker"])
      ]
    foreach RiskTaking_list
      [
        x -> (if who = x [set Agentt_type "Risk_taker"])
      ]
    ]

    ;; step 1: Social learning: Ask around. Do any of my neighbors have better solutions?
    let best-solution solution   ; the variable "best-solution" is the current solution of the agent
    let better-one? false
    set Others_superiority_perception 0
    set Self_superiority_perception 0
    if Superior_Perception = "Others"    ; If there is inferiority bias
      [
        set Others_superiority_perception random-float  Perception_Superiority_level
      ]

     if Superior_Perception = "Self"    ; If there is superiority bias
      [
        set Self_superiority_perception random-float  Perception_Superiority_level    ; The bias for each agent is a random number between zero and superiority level
      ]

    ask link-neighbors
    [
      if ((evaluate-fitness solution) + Others_superiority_perception )  > ((evaluate-fitness best-solution) + self_superiority_perception)  ;; neighbors solution > current solution
      [
        if not c_error      ; If there is not communication noise
        [
        set best-solution solution
        set better-one? true
        ]

       if c_error       ;if we have communication noise
       [ let probability ( 100 - Copy_error)
        foreach range n
          [ x -> if random 100 < probability   ; The chance of each elements of a better solution to be adopted is 100 - communication noise (aka copy_error)
                 [
                 set best-solution (replace-item x best-solution (item x solution))
                 ]
          ]
        set better-one? true
       ]

      ]
    ]

    ;; step 2: EXPLORE: If no one has a better solution, explore the landscape (aka individual learning)
    if not better-one?
    [

      ; 1: Defining Normal agents behaviour
      if Agentt_type = "Normal"
      [
        let found-solution explore  ;filipping one element of the current solution
        set cost (cost + 1)      ; cost of filipping one element of the current solution, we compute linear cost for normal agents.
        set solution_list lput found-solution solution_list
        if evaluate-fitness found-solution > evaluate-fitness solution  ; comparing the newly generated solution with the current solution
        [ set solution found-solution
          set best-solution solution
        set better-one? true
         ]
      ]

      ; 2: Defining hard working agents behaviour
     if Agentt_type = "hard_worker"
      [
        repeat exploring_dimension
        [
          let found-solution explore       ;;generating a new solution
          set solution_list lput found-solution solution_list  ;; observer for tried solutions
          if evaluate-fitness found-solution > evaluate-fitness solution
          [
            set solution found-solution ;
            set best-solution solution  ;
            set better-one? true
          ]
        ]
      ;;;;;computing hardworking cost in a timestep based on cost type (linear, super linear, sublinear);;;;;;;;;;;;;;;

        if cost_type = "linear"
          [
          set cost (cost + exploring_dimension)  ; in each time step the cost = cost + H (aka hardworking level)
          ]

        if cost_type = "superlinear"
          [
         ;foreach range repeatnumber [ x -> set cost (cost + (1.1 ^ (x + 1))) ]
          set cost (cost + (exploring_dimension ^ 2))
          ]
        if cost_type = "sublinear"
          [
         ;foreach range repeatnumber [ x -> set cost (cost + (1.1 ^ (1 /(x + 1)))) ]
          set cost (cost + (exploring_dimension ^ (1 / 2 )))
          ]
      ]

      ; 3: Defining risk taker agents behaviour
    if Agentt_type = "Risk_taker"
      [
        let orig_solution solution
        let repeatnumber (1 + random (risk_dimension - 1)) ; set the number of changes in the range of 1 to R

        repeat  repeatnumber  ;generating a new solution by taking-risk
        [
          let found-solution explore
          set solution found-solution
        ]

 ;;;;;;;computing the risk-taking cost in a tick;;;;;;;;;;;
        if cost_type = "linear"
          [
          set cost (cost + repeatnumber)
          ]

        if cost_type = "superlinear"
          [
         ;foreach range repeatnumber [ x -> set cost (cost + (1.1 ^ (x + 1))) ]
          set cost (cost + (repeatnumber ^ 2))
          ]
        if cost_type = "sublinear"
          [
         ;foreach range repeatnumber [ x -> set cost (cost + (1.1 ^ (1 /(x + 1)))) ]
          set cost (cost + (repeatnumber ^ (1 / 2 )))
          ]
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

        set solution_list lput solution solution_list
        ifelse evaluate-fitness orig_solution > evaluate-fitness solution
        [
          set solution orig_solution
        ]
        [
          set better-one? True
        ]
        set best-solution solution
      ]

      ;4: Defining hybrid agents behaviour
     if Agentt_type = "RT_HW"
      [
        let orig_solution solution ; saving the origin spot
        let Hybrid_repeatnumber (1 + random (risk_dimension - 1))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;computing cost for hybrid agents ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
        if cost_type = "linear"
          [
          set cost (cost + (Hybrid_repeatnumber + exploring_dimension))
          ]
        if cost_type = "superlinear"
          [
          set cost cost + ((Hybrid_repeatnumber + exploring_dimension) ^ 2)
          ]
        if cost_type = "sublinear"
          [
          set cost cost + ((Hybrid_repeatnumber + exploring_dimension) ^ (1 / 2 ))
          ]
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
        repeat Hybrid_repeatnumber    ;begining of risk taking loop - exploration
            [ let risk_exp_solution explore
              set solution risk_exp_solution
            ]

        set solution_list lput solution solution_list
        repeat exploring_dimension ; start of hardworking loop
              [
                let found_solution explore ;finding a new solution
                set solution_list lput found_solution solution_list
                if evaluate-fitness found_solution  > evaluate-fitness solution ; conditionally updating the solution
                [
                  set solution found_solution
                ]
              ]
        ifelse evaluate-fitness orig_solution > evaluate-fitness solution ; checking against the original solution- updating back to the original solution if afterall the original solution better
              [
                set solution orig_solution
        ]
        [
          set better-one? true
        ]
        set best-solution solution
      ]
    ]

    set solution best-solution
    let this-color precision evaluate-fitness solution 2
    ifelse enable-space-analysis
    [ set color palette:scale-scheme "Sequential" "Reds" 7 this-color 0 1 ]
    [ set label this-color ]
    set solution_value evaluate-fitness solution
    set sol_list_test lput solution sol_list_test

  ]
  tick

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                 ;;;
;;; the following set of functions  ;;;
;;; defines the agent behavior.     ;;;
;;;                                 ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to spawn-turtles

  create-turtles Number-Of-Agents [
    ;; each turtle starts with a randomly generated solution
    set solution n-values n [ random b ]    ;; it creates n digits of random number less than b, b is 2 so the result would be the string of 0 or 1
    set solution_list lput solution solution_list
    set sol_list_test lput solution sol_list_test
    set label-color black
    set color palette:scale-scheme "Sequential" "Reds" 7 0 0 1
  ]
  if copy_agent
  [ ask turtles
    [hatch copy_number]
  ]
  set-default-shape turtles "circle"
    layout-circle (sort turtles) max-pxcor - 1
end


to-report explore    ;this provide a new similar solution with hamming distance of 1
  ;; set the variable 'new answer' to be the turtle's solution variable
  ;; with a randomly chosen item (from 0 to n) replaced with a random value or 0 or 1
  ;; from 0 to b that does not include the one already there.
  let replaced-item random n    ;n is N, here it just choose one digit index in the solution string to change in the following line
  let new-answer replace-item replaced-item solution (item random (b - 1) list-not-x (item replaced-item solution) 0 b )
  ;inside the paranthesis should give you 0 or 1. whatever is not in the string already. (item 0 list_not_X ( Nth item in the solution) 0 b )
  ;list-not-x (item replaced-item solution) 0 b = from 0 to b which is 0,1,2 make a list that exclude the nth. so [0,2] or [1,2] then choose 0th item
  report new-answer
end









;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                               ;;;
;;; the following set of methods  ;;;
;;; also known as 'functions'     ;;;
;;; also known as 'to-do-things'  ;;;
;;; defines the nk space.         ;;;
;;;                               ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;                                                                                           ;;
  ;; NK space is generated according to Appendix A in                                          ;;
  ;;      Lazer, D., & Friedman, A. (2007). The network structure of exploration and           ;;
  ;;      exploitation. Administrative Science Quarterly, 52(4), 667-694.                      ;;
  ;; There are two key components to this nk-space:                                            ;;
  ;;    a)  the value of a given "allele," which is here represented as a numeric string.      ;;
  ;;        - an agent has N alleles                                                           ;;
  ;;    b)  the pairs of digits that make up each allele.  these are randomly chosen           ;;
  ;;        - each allele has k digits                                                         ;;
  ;;                                                                                           ;;
  ;; The one departure from Lazer's implementation is that here we allow 'b' to be >2, meaning ;;
  ;; that our numeric strings CAN be bitstrings, as his were, but do not have to be.           ;;
  ;;                                                                                           ;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;




to define-allele-values
  ;; this function defines the value of each
  ;; allele of length k.  together with set-interdependencies
  ;; this defines the nk-space by creating an identifiable
  ;; value for any nk-string
  ;;
  ;; we're not actually directly defining the alleles:  rather,
  ;; we're defining them by their index in a list.  later,
  ;; a converter will take an allele (0 1 1) and convert it
  ;; to a decimal index.
  ;;
  ;; for a given index - allele - the value is randomly chosen
  ;; from a given distribution.

  set nk-space []
  let i 0
  repeat B ^ (K + 1) [
    set nk-space lput nk-distribution nk-space ;it makes a b^(k+1) long string of digits less than 1000 [34,654,342,....,534]
    set i i + 1
  ]

end

to set-interdependencies
  ;; for each digit-location in the numeric string,
  ;; this function sets (k - 1) other digit-locations
  ;; to define alleles of size k.

  if k > (n - 1)
  [
    show "Error!  K cannot be greater than N-1.  Setting K to N-1."
    set k (n - 1)
  ]

  set allele-map []
  let i 0
  repeat n
  [
    set allele-map lput fput i n-of k (list-not-x i 0 n) allele-map   ; allele-map is a list, we add k randomly choosen digits from a list from 0 to n excluding i which
    set i i + 1 ; is our corrent digit-location
  ]
end



to-report nk-distribution  ; it give a random number between 0 and 1000
  ;; this function simply outputs a random number
  ;; from the appropriate distribution for the
  ;; desired nk-space.


  let p item (random numpeaks) plist

  let bin_ct 0
  repeat 1000 [
      if random-float 1 < p
      [
        set bin_ct bin_ct + 1
      ]
  ]
  report bin_ct
end


to-report evaluate-fitness [ test-solution ]
  let fitness 0
  let i 0
  while [i < n]
  [
    let this-allele []
    foreach item i allele-map
    [ [?1] ->
      set this-allele lput item ?1 test-solution this-allele
    ]
    set fitness fitness + item convert-allele this-allele nk-space
    set i i + 1
  ]
  set fitness (fitness / n)

  ; If max-value has been calculated,
  ; normalize the score.

  if (global-max != 0) [
    set fitness fitness / global-max
    set fitness fitness ^ 8

  ]

  report fitness
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                               ;;;
;;; some generic, non-model       ;;;
;;; utilities.                    ;;;
;;;                               ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to-report list-not-x [x x.min x.max]  ; it make a list without x
  ;; a little utility to draw-without-replacement
  ;; from the range x.min to x.max excluding x.
  let i x.min
  let report-list []
  repeat (x.max - x.min)
  [
    if i != x
    [
      set report-list lput i report-list
    ]
    set i i + 1
  ]
  report report-list
end

to-report convert-allele [string]     ;it simlpy convert binary to decimal
  ;; this utility converts a base b string into
  ;; a decimal number - the index location of that
  ;; allele's value.
  ;; eg, when b = 2, this is a decimal-to-binary converter.
  let i 0
  let decimal-output 0
  repeat length string
  [
    set decimal-output decimal-output + ( ( b ^ (length string - i - 1) ) * item i string )
    set i i + 1
  ]
  report decimal-output
end

to-report convert-to-allele [ decimal ]
  ;; reverse process of above - so if b=2, this
  ;; is a decimal-to-binary converter.


  let output-string []
  repeat n [
    set output-string fput (decimal mod b) output-string
    set decimal floor (decimal / b)
  ]

  report output-string
end


;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;
;;;
;;; much of this network construction code was
;;; copy-pasted from the uri wilensky small worlds model
;;;
;;;
;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;

;;;NETWORKS;;;

to wire-ringlat
  layout-circle (sort turtles) max-pxcor - 1   ; we already had it

  layout-circle (sort turtles with [ who mod 2 = 0] ) max-pxcor - 4
  if Network_type = "fully_connected_network" [ask turtles [ create-links-with other turtles ]
  let hesab do-calculations]





  ;;;;;;SMALL_WOLD;;;;;;;;;;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  if Network_type = "small_world"[

  ;; set up a variable to determine if we still have a connected network
  ;; (in most cases we will since it starts out fully connected)
  let success? false
  while [not success?] [
    ;; we need to find initial values for lattice
    wire-them
    ;;calculate average path length and clustering coefficient for the lattice
    set success? do-calculations
  ]

  ;; setting the values for the initial lattice
  set clustering-coefficient-of-lattice clustering-coefficient
  set average-path-length-of-lattice average-path-length
  set number-rewired 0
  repeat rewire_time [rewire-one]


  ]



  if Network_type = "Erdos–Renyi" [  ask turtles [
    ;; we use "self > myself" here so that each pair of turtles
    ;; is only considered once
    create-links-with turtles with [self > myself and random-float 1.0 < Erdos_probability]]
  let hesab do-calculations]

  if Network_type = "random" [  if degree > max-links [ set degree max-links ]
  while [count links < degree] [
    ;; Note that if the link already exists, nothing happens
      ask one-of turtles [ create-link-with one-of other turtles ]]
  let hesab do-calculations]

  if Network_type = "lattice" [


  ;; iterate over the turtles
  let ni 0
  while [ni < count turtles]
  [
    ;; make edges with the next two neighbors
    ;; this makes a lattice with average degree of 4
    let z 1
    while [z <= floor (degree / 2)]
    [
      ask turtle ni [ create-link-with turtle ((ni + z) mod count turtles) ]
      set z z + 1
    ]
    set ni ni + 1
  ]
  let hesab do-calculations]

end



;; connects the two turtles
to make-edge [node1 node2]
  ask node1 [ create-link-with node2  [
    set rewired? false
  ] ]
end

to-report max-links  ; this is for the use of random network
  ;; report the maximum number of links that can be added
  ;; to a random network, given the specified number
  ;; of nodes, with 1000 as an arbitrary upper bound
  report min (list (number-of-agents * (number-of-agents - 1) / 2) 1000)
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                            ;;;
;;;   game state computations  ;;;
;;;                            ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report number-of-unique-solutions
  let solution-set []
  ask turtles
  [
    let already-there? false
    foreach solution-set
    [ [?1] ->            ; [?1] is just space holder; for p in solution-set if solution = p
      if solution = ?1
      [
        set already-there? true
      ]
    ]
    if not already-there?
    [
      set solution-set lput solution solution-set
    ]
  ]

  report length solution-set
end


to-report average-score
  let avg 0
  ask turtles [
    set avg avg + evaluate-fitness solution
  ]
  report ( avg / count turtles )
end

to-report cost_monitor
  report cost
end

to-report Team_SD-score
  let mylist []
  ask turtles [
    set mylist lput  evaluate-fitness solution mylist
  ]
  report (standard-deviation mylist )
end

to-report explored_solution
  let explored_solution_list []
  set explored_solution_list solution_list
  report explored_solution_list
end

to determine-peaks
  if enable-space-analysis [
    ;; WARNING!!!
    ;; this function can easily take a long time
    ;; if n or b are too high...

    ;; determine decimal value of highest numerical-string
    let mylist []
    repeat n
    [
      set mylist lput (b - 1) mylist
    ]

    let best-answer 0
    let worst-answer 999999999
    let i 0
    while [i <= convert-allele mylist]
    [
      let this-value evaluate-fitness (convert-to-allele i)
      if this-value > best-answer
      [
        set best-answer this-value
      ]
      if this-value < worst-answer
      [
        set worst-answer this-value
      ]
      set i i + 1
    ]

    set global-max best-answer
    set global-min worst-answer
  ]
end

to-report global-peak

  ;; report global max without recalculating
  report global-max
end

to-report global-minimum

  ;; report global min without recalculating

  report global-min
end


;;;;;;;;;;;;;;;;;;;;;;;small_world_functions;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to rewire-one


  ;; record which button was pushed
  set rewire-one? true
  set rewire-all? false

  let potential-edges links with [ not rewired? ]
  ifelse any? potential-edges [
    ask one-of potential-edges [
      ;; "a" remains the same
      let node1 end1
      ;; if "a" is not connected to everybody
      if [ count link-neighbors ] of end1 < (count turtles - 1)
      [
        ;; find a node distinct from node1 and not already a neighbor of node1
        let node2 one-of turtles with [ (self != node1) and (not link-neighbor? node1) ]
        ;; wire the new edge
        ask node1 [ create-link-with node2 [set rewired? true ] ]

        set number-rewired number-rewired + 1  ;; counter for number of rewirings

        ;; remove the old edge
        die
      ]
    ]
    ;; plot the results
    let connected? do-calculations
    update-plots
  ]
  [ user-message "all edges have already been rewired once" ]
end

to rewire-all

  ;; record which button was pushed
  set rewire-one? false
  set rewire-all? true

  ;; set up a variable to see if the network is connected
  let success? false

  ;; if we end up with a disconnected network, we keep trying, because the APL distance
  ;; isn't meaningful for a disconnected network.
  while [not success?] [
    ;; kill the old lattice, reset neighbors, and create new lattice
    ask links [ die ]
    wire-them
    set number-rewired 0

    ask links [

      ;; whether to rewire it or not?
      if (random-float 1) < rewiring-probability
      [
        ;; "a" remains the same
        let node1 end1
        ;; if "a" is not connected to everybody
        if [ count link-neighbors ] of end1 < (count turtles - 1)
        [
          ;; find a node distinct from node1 and not already a neighbor of node1
          let node2 one-of turtles with [ (self != node1) and (not link-neighbor? node1) ]
          ;; wire the new edge
          ask node1 [ create-link-with node2 [set rewired? true ] ]

          set number-rewired number-rewired + 1  ;; counter for number of rewirings
          set rewired? true
        ]
      ]
      ;; remove the old edge
      if (rewired?)
      [
        die
      ]
    ]

    ;; check to see if the new network is connected and calculate path length and clustering
    ;; coefficient at the same time
    set success? do-calculations
  ]

  ;; do the plotting
  update-plots
end

;; do-calculations reports true if the network is connected,
;;   and reports false if the network is disconnected.
;; (In the disconnected case, the average path length does not make sense,
;;   or perhaps may be considered infinite)
to-report do-calculations

  ;; set up a variable so we can report if the network is disconnected
  let connected? true

  ;; find the path lengths in the network
  find-path-lengths

  let num-connected-pairs sum [length remove infinity (remove 0 distance-from-other-turtles)] of turtles

  ;; In a connected network on N nodes, we should have N(N-1) measurements of distances between pairs,
  ;; and none of those distances should be infinity.
  ;; If there were any "infinity" length paths between nodes, then the network is disconnected.
  ;; In that case, calculating the average-path-length doesn't really make sense.
  ifelse ( num-connected-pairs != (count turtles * (count turtles - 1) ))
  [
      set average-path-length infinity
      ;; report that the network is not connected
      set connected? false
  ]
  [
    set average-path-length (sum [sum distance-from-other-turtles] of turtles) / (num-connected-pairs)
  ]
  ;; find the clustering coefficient and add to the aggregate for all iterations
  find-clustering-coefficient

  ;; report whether the network is connected or not
  report connected?
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Clustering computations ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report in-neighborhood? [ hood ]
  report ( member? end1 hood and member? end2 hood )
end


to find-clustering-coefficient
  ifelse all? turtles [count link-neighbors <= 1]
  [
    ;; it is undefined
    ;; what should this be?
    set clustering-coefficient 0
  ]
  [
    let total 0
    ask turtles with [ count link-neighbors <= 1]
      [ set node-clustering-coefficient "undefined" ]
    ask turtles with [ count link-neighbors > 1]
    [
      let hood link-neighbors
      set node-clustering-coefficient (2 * count links with [ in-neighborhood? hood ] /
                                         ((count hood) * (count hood - 1)) )
      ;; find the sum for the value at turtles
      set total total + node-clustering-coefficient
    ]
    ;; take the average
    set clustering-coefficient total / count turtles with [count link-neighbors > 1]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Path length computations ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Implements the Floyd Warshall algorithm for All Pairs Shortest Paths
;; It is a dynamic programming algorithm which builds bigger solutions
;; from the solutions of smaller subproblems using memoization that
;; is storing the results.
;; It keeps finding incrementally if there is shorter path through
;; the kth node.
;; Since it iterates over all turtles through k,
;; so at the end we get the shortest possible path for each i and j.

to find-path-lengths
  ;; reset the distance list
  ask turtles
  [
    set distance-from-other-turtles []
  ]

  let i 0
  let j 0
  let kk 0
  let node1 one-of turtles
  let node2 one-of turtles
  let node-count count turtles
  ;; initialize the distance lists
  while [i < node-count]
  [
    set j 0
    while [j < node-count]
    [
      set node1 turtle i
      set node2 turtle j
      ;; zero from a node to itself
      ifelse i = j
      [
        ask node1 [
          set distance-from-other-turtles lput 0 distance-from-other-turtles
        ]
      ]
      [
        ;; 1 from a node to it's neighbor
        ifelse [ link-neighbor? node1 ] of node2
        [
          ask node1 [
            set distance-from-other-turtles lput 1 distance-from-other-turtles
          ]
        ]
        ;; infinite to everyone else
        [
          ask node1 [
            set distance-from-other-turtles lput infinity distance-from-other-turtles
          ]
        ]
      ]
      set j j + 1
    ]
    set i i + 1
  ]
  set i 0
  set j 0
  let dummy 0
  while [kk < node-count]
  [
    set i 0
    while [i < node-count]
    [
      set j 0
      while [j < node-count]
      [
        ;; alternate path length through kth node
        set dummy ( (item kk [distance-from-other-turtles] of turtle i) +
                    (item j [distance-from-other-turtles] of turtle kk))
        ;; is the alternate path shorter?
        if dummy < (item j [distance-from-other-turtles] of turtle i)
        [
          ask turtle i [
            set distance-from-other-turtles replace-item j distance-from-other-turtles dummy
          ]
        ]
        set j j + 1
      ]
      set i i + 1
    ]
    set kk kk + 1
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Edge Operations for small world network ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; creates a new lattice
to wire-them
  ;; iterate over the turtles
  let nn 0
  while [nn < count turtles]
  [
    ;; make edges with the next two neighbors
    ;; this makes a lattice with average degree of 4
    make-edge turtle nn
              turtle ((nn + 1) mod count turtles)
    make-edge turtle nn
              turtle ((nn + 2) mod count turtles)
    set nn nn + 1
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
230
16
667
454
-1
-1
13.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

INPUTBOX
942
39
992
99
n
20.0
1
0
Number

INPUTBOX
1004
37
1054
97
k
0.0
1
0
Number

BUTTON
73
10
136
43
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
43
206
149
266
number-of-agents
100.0
1
0
Number

TEXTBOX
924
12
1074
62
NK Space Variables
16
0.0
1

BUTTON
70
45
143
81
One Step
run-step
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
71
88
141
126
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1067
274
1379
432
Number of Unique Solutions
Time
Unique Solutions
0.0
20.0
0.0
20.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot number-of-unique-solutions"

PLOT
1066
13
1397
163
Average Score 
Time
Score
0.0
20.0
0.0
1000.0
true
false
"determine-peaks\nif enable-space-analysis [\n   set-plot-y-range 0 1\n]" ""
PENS
"default" 1.0 0 -16777216 true "" "plot average-score"

TEXTBOX
911
104
1068
136
The nk-space is randomly generated every time you click 'setup'
9
0.0
1

SWITCH
1067
176
1245
209
enable-space-analysis
enable-space-analysis
0
1
-1000

TEXTBOX
1252
176
1402
209
Warning!  NK Space analysis algorithm is very slow for large N and K.
9
0.0
1

SLIDER
23
558
195
591
degree
degree
0
50000
50.0
1
1
NIL
HORIZONTAL

INPUTBOX
42
296
149
356
exploring_dimension
5.0
1
0
Number

CHOOSER
22
457
210
502
Network_type
Network_type
"lattice" "small_world" "random" "fully_connected_network" "Erdos–Renyi"
2

MONITOR
905
246
976
291
NIL
count links
17
1
11

TEXTBOX
905
230
1017
254
Count links of  network
9
0.0
1

TEXTBOX
33
592
183
627
Network degree of ring lattice or number of  links in the Random network 
9
0.0
1

SLIDER
23
631
195
664
Erdos_probability
Erdos_probability
0
1
0.56
0.01
1
NIL
HORIZONTAL

TEXTBOX
208
593
360
611
Small world parameters:
12
0.0
1

SLIDER
208
617
380
650
rewiring-probability
rewiring-probability
0
1
0.83
0.01
1
NIL
HORIZONTAL

BUTTON
212
668
301
701
NIL
rewire-one
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
307
668
385
701
NIL
rewire-all
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
1137
596
1266
641
SD_Of_TEAM_scores
Team_SD-score
5
1
11

PLOT
1141
444
1341
594
Team SD
time
SD
0.0
20.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot Team_SD-score"

CHOOSER
43
158
181
203
Agent_type
Agent_type
"Risk_taker" "Normal" "hard_worker" "RT_HW"
2

TEXTBOX
47
135
197
155
Agents Parameters:
16
0.0
1

TEXTBOX
29
434
179
454
Network Parameters:
16
0.0
1

TEXTBOX
26
522
176
567
Lattice or Random parameters:
12
0.0
1

INPUTBOX
42
374
134
434
risk_dimension
5.0
1
0
Number

TEXTBOX
42
360
192
378
For risk_taker agents:
12
0.0
1

TEXTBOX
41
276
191
294
For Hard working agents:
11
0.0
1

INPUTBOX
410
637
501
697
rewire_time
3.0
1
0
Number

MONITOR
232
724
360
769
NIL
clustering-coefficient
3
1
11

MONITOR
413
724
541
769
NIL
average-path-length
3
1
11

SWITCH
942
324
1051
357
Mix_team
Mix_team
1
1
-1000

INPUTBOX
911
377
972
437
HW_num
18.0
1
0
Number

INPUTBOX
985
374
1047
434
RT_num
0.0
1
0
Number

TEXTBOX
917
446
1106
475
Number of hardworking and risk taking agents in Mix teams
11
0.0
1

SWITCH
921
135
1045
168
Copy_agent
Copy_agent
1
1
-1000

INPUTBOX
901
168
1056
228
copy_number
49.0
1
0
Number

MONITOR
696
507
769
552
cost
cost
17
1
11

CHOOSER
547
508
685
553
cost_type
cost_type
"linear" "superlinear" "sublinear"
0

PLOT
566
554
766
704
Cost time
time
cost
0.0
20.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot cost_monitor"

SLIDER
587
757
759
790
Copy_error
Copy_error
0
100
20.0
10
1
NIL
HORIZONTAL

SWITCH
588
724
691
757
c_error
c_error
0
1
-1000

CHOOSER
825
581
976
626
Superior_Perception
Superior_Perception
"None" "Self" "Others"
0

SLIDER
799
627
1027
660
Perception_Superiority_level
Perception_Superiority_level
0
1
0.09
0.01
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This is a model of collective problem-solving of networked agenets on an NK landscape.  It is based on:

Lazer, D., & Friedman, A. (2007). The network structure of exploration and exploitation. Administrative Science Quarterly, 52(4), 667-694.


## The Model


The population: Agents are organized in a network and each begins with a random problem solution. Agents are either normal, hardworking, risk-taking, or hybrid. 
Dynamics: At each time step, an agent first compares its current solution with its network neighbors. If a better solution is found, the agent then adopts that solution. Otherwise, the agent explores the solution space. The simulation stops when agents converge at a unique solution.  

Normal agents generate a new solution by changing one dimension of their current solution. The agent then compares the score of the new solution with the previous solution and adopts the solution with the highest score.

Hardworking agents generate f > 1 new solution during a single round of exploration by randomly changing one dimension of the current solution. The agent then compares the score of the previous solution and the f new solutions and adopts the solution with the highest score. 

Risk-taking agents generate a new solution by randomly changing D >1 dimensions of the current solution. The newly built solution is compared with the current solution. The solution with the higher score will be adopted. 

Hybrid RT_HW agents in the exploration phase, these agents first behave in a manner similar to a risk-taking agent and then behave as a hardworking agent. Thus,  this hybrid generates a new solution by randomly changing the D >1 dimensions of the current solution. The newly built solution will use a seed solution, and the agent generates f > 1 new solution by randomly changing one dimension of the current solution. The agent then compares the score of the previous solution and the new solutions and adopts the solution with the highest score.

## HOW IT WORKS

Each agent starts with a randomly chosen "solution," represented by a bit string where each slot has B possible values. At each time step, an agent first checks to see if any neighbors have a better solution.  If they do, the agent will "exploit" that social information by adopting the best solution from among their neighbors.

If neighbors do not offer a better solution, an agent will "explore" by randomly changing one bit of their bit-string solution; if that new solution is better, they keep that new solution.  The value of a solution is determined by a randomly generated NK space.


An "NK Space" is a way of mapping solutions to complex problems on a fitness landscale offering "tunable ruggedness."  A "fitness landscape" is a landscape of all the possible solutions to a problem, where "fitness" refers to how good a solution is.

By increasing "K" you increase the interdependence between parts of the solution -- so that with higher K, changing one choice impacts the fitness of other choices.



## HOW TO USE IT

Set the network topology using the "network type" parameters.
Select Agent type and the corresponding level of hardworking or risk taking for agents that requere that. 

Set if there is any communication noise. Set the level of communication noise if there is any noise. 

Set if there is any superiority or inferiority bias. Set the level of perception bias if there is any bias. 

Set the NK space parameters by setting N and K.  N is the length of the bit-string (the number of factors that must be considered in the solution) and K is the extent of interdependency, or complexity of the problem.





## NETLOGO FEATURES

This model uses the 'array' extension to generate the NK space.

## CREDITS AND REFERENCES

Lazer, D., & Friedman, A. (2007). The network structure of exploration and exploitation. Administrative Science Quarterly, 52(4), 667-694.

## COPYRIGHT AND LICENSE

Copyright 2017 Joshua Becker

![CC BY-NC-SA 3.0](https://licensebuttons.net/l/by-nc-sa/3.0/88x31.png)

This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 License.  To view a copy of this license, visit https://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.

<!-- 2017 -->
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="2021_20Normal_K10_linear" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_agent">
      <value value="&quot;Off&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost_type">
      <value value="&quot;linear&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="&quot;Off&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20Normal_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100Normal_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100Normal_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT2_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT3_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT4_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT5_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT6_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT7_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT8_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT9_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT10_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT11_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT12_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT13_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT14_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT15_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT16_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT17_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT18_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT19_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT20_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT2_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT3_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT4_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT5_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT6_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT7_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT8_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT9_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT10_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT11_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT12_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT13_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT14_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT15_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT16_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT17_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT18_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT19_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100RT20_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT1_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT2_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT3_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT4_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT5_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT6_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT7_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT8_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT9_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT10_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT11_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT12_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT13_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT14_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT15_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT16_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT17_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT18_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT19_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT20_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT1_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT2_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT3_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT4_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT5_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT6_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT7_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT8_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT9_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT10_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT11_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT12_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT13_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT14_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT15_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT16_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT17_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT18_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT19_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_20RT20_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT0_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT10_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT20_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT30_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT40_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT50_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT60_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT70_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="70"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT80_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="80"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT90_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="90"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT100_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT0_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT10_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT20_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT30_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT40_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT50_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT60_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT70_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="70"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT80_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="80"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT90_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="90"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020Mix_100RT100_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="HW_num">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RT_num">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20hyb_5RT5HW_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20hyb_10RT5HW_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20hyb_5RT10HW_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20hyb_10RT10HW_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20hyb_5RT5HW_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20hyb_10RT5HW_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20hyb_5RT10HW_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_20hyb_10RT10HW_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100hyb_5RT5HW_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100hyb_10RT5HW_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100hyb_5RT10HW_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100hyb_10RT10HW_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100hyb_5RT5HW_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100hyb_10RT5HW_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100hyb_5RT10HW_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100hyb_10RT10HW_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;RT_HW&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <metric>explored_solution</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100_copy20agent_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_100_copy20agent_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_200_copy20agent_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_200_copy20agent_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_200Normal_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_200Normal_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_400Normal_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2020_400Normal_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="___________100Agents___dif_copy" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <metric>explored_solution</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_2uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_4uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_10uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_20uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_25uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_50uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="___________100HWAgents___dif_copy" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <metric>explored_solution</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_2uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_4uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_10uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_20uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_25uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_50uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_2uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_4uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_10uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_20uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_25uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_50uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_2uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_4uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_10uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_20uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_25uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100Normal_50uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_2uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_4uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_10uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_20uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_25uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW5_50uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_2uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_4uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_10uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_20uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_25uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100HW10_50uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="___________100RT__Agents___dif_copy" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <metric>explored_solution</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_2uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_4uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_10uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_20uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_25uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_50uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_2uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_4uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_10uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_20uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_25uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_50uniq_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="___________100RT__Agents_K0__dif_copy" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <metric>explored_solution</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_2uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_4uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_10uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_20uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_25uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT5_50uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_2uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_4uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_10uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_20uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_25uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="100RT10_50uniq_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="___________SD2021_____" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_100rep" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_200rep" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_10rep" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_20rep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_30rep" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_40rep" repetitions="40" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_50rep" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_60rep" repetitions="60" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_70rep" repetitions="70" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_80rep" repetitions="80" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_90rep" repetitions="90" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_300rep" repetitions="300" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_400rep" repetitions="400" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_100rep" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_200rep" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_10rep" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_20rep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_30rep" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_40rep" repetitions="40" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_50rep" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_60rep" repetitions="60" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_70rep" repetitions="70" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_80rep" repetitions="80" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_90rep" repetitions="90" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_300rep" repetitions="300" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_400rep" repetitions="400" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_100rep" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_200rep" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_300rep" repetitions="300" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_400rep" repetitions="400" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_10rep" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_20rep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_30rep" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_40rep" repetitions="40" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_50rep" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_60rep" repetitions="60" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_70rep" repetitions="70" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_80rep" repetitions="80" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_90rep" repetitions="90" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_100rep" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_90rep" repetitions="90" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_80rep" repetitions="80" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_70rep" repetitions="70" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_60rep" repetitions="60" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_50rep" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_40rep" repetitions="40" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_30rep" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_20rep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_10rep" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_400rep" repetitions="400" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_300rep" repetitions="300" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_200rep" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_100rep" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_200rep" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_300rep" repetitions="300" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_400rep" repetitions="400" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_90rep" repetitions="90" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_80rep" repetitions="80" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_70rep" repetitions="70" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_60rep" repetitions="60" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_50rep" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_40rep" repetitions="40" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_30rep" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_20rep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_10rep" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_10rep" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_20rep" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_30rep" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_40rep" repetitions="40" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_50rep" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_60rep" repetitions="60" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_70rep" repetitions="70" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_80rep" repetitions="80" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_90rep" repetitions="90" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_400rep" repetitions="400" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_300rep" repetitions="300" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_200rep" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_100rep" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="__RT_&amp;_Normal__________C_NOISE_____" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_2rep_test" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RT_TEST_with_previous_RT_Type_____________________" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT2_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT3_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT4_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT5_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT6_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT7_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT8_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT9_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT10_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT11_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT12_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT13_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT14_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT15_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT16_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT17_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT18_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT19_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT20_K10_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT2_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT3_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT4_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT5_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT6_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT7_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT8_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT9_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT10_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT11_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT12_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT13_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT14_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT15_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT16_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT17_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="17"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT18_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT19_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_100RT20_K0_ring4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="__HW__________C_NOISE_____" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_1Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_2Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_3Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_4Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_5Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_6Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_7Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_8Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_9Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_10Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_11Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_12Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_13Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_14Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_15Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_16Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_17Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_18Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_19Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_30Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_40Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="__RT_&amp;_Normal__________P_S&amp;O_NOISE_____" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_agent">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copy_number">
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_1PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_05PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_2PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_3PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_4PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_5PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_6PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_7PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_8PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_9PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_10PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_11PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_12PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_13PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_14PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_15PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_16PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_17PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_18PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_19PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_20PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_30PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_40PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_50PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_1Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_05Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_2Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_3Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_4Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_5Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_6Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_7Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_8Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_9Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_10Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_11Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_12Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_13Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_14Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_15Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_16Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_17Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_18Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_19Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_20Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_30Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_40Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_50Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_1PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_2PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_3PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_4PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_5PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_6PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_7PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_8PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_9PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_10PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_11PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_12PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_13PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_14PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_15PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_16PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_17PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_18PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_19PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_20PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_30PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_40PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_50PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_05PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_1Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_2Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_3Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_4Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_5Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_6Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_7Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_8Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_9Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_10Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_11Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_12Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_13Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_14Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_15Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_16Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_17Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_18Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_19Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_20Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_30Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_40Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_50Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_05Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_1PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_2PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_3PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_4PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_5PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_6PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_7PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_8PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_9PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_10PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_11PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_12PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_13PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_14PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_15PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_16PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_17PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_18PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_19PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_20PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_30PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_40PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_50PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_05PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_1PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_2PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_3PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_4PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_5PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_6PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_7PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_8PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_9PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_10PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_11PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_12PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_13PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_14PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_15PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_16PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_17PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_18PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_19PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_20PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_30PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_40PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_50PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_1Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_2Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_3Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_4Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_5Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_6Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_7Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_8Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_9Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_10Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_11Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_12Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_13Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_14Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_15Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_16Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_17Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_18Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_19Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_20Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_30Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_40Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_50Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_05Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_1Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_2Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_3Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_4Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_5Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_6Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_7Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_8Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_9Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_10Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_11Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_12Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_13Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_14Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_15Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_16Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_17Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_18Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_19Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_20Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_30Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_40Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_50Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_05Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_1PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_2PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_3PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_4PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_5PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_6PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_7PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_8PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_9PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_10PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_11PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_12PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_13PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_14PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_15PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_16PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_17PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_18PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_19PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_20PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_30PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_40PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_50PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_05PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_1PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_2PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_3PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_4PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_5PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_6PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_7PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_8PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_9PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_10PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_11PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_12PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_13PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_14PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_15PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_16PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_17PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_18PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_19PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_20PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_30PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_40PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_50PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_05PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_1Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_2Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_3Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_4Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_5Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_6Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_7Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_8Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_9Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_10Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_11Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_12Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_13Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_14Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_15Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_16Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_17Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_18Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_19Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_20Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_30Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_40Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_50Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_05Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_1Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_2Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_3Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.03"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_4Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_5Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_6Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.06"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_7Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.07"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_8Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_9Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.09"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_10Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_11Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_12Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_13Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_14Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_15Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_16Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_17Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_18Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_19Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_20Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_30Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_40Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_50Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_05Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.005"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_500rep" repetitions="500" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_600rep" repetitions="600" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_700rep" repetitions="700" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_800rep" repetitions="800" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_900rep" repetitions="900" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_1000rep" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_500rep" repetitions="500" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_600rep" repetitions="600" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_700rep" repetitions="700" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_800rep" repetitions="800" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_900rep" repetitions="900" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_1000rep" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_500rep" repetitions="500" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_600rep" repetitions="600" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_700rep" repetitions="700" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_800rep" repetitions="800" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_900rep" repetitions="900" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_1000rep" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_500rep" repetitions="500" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_600rep" repetitions="600" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_700rep" repetitions="700" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_800rep" repetitions="800" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_900rep" repetitions="900" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_1000rep" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_500rep" repetitions="500" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_600rep" repetitions="600" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_700rep" repetitions="700" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_800rep" repetitions="800" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_900rep" repetitions="900" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_1000rep" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_500rep" repetitions="500" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_600rep" repetitions="600" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_700rep" repetitions="700" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_800rep" repetitions="800" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_900rep" repetitions="900" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_1000rep" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_25Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_35Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_45Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_25Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_35Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_45Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_25PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_35PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_45PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_25PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_35PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_45PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_25Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_35Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_45Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_25Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_35Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_45Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_25PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_35PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_45PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_45PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_25PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_35PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_25PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_35PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_45PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_25PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_35PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_45PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_25Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_35Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_45Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_25Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_35Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_45Pothers_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Others&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_25Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_35Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_45Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_45Cnoise" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW10_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW15_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT10_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT15_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT20_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW20_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test2022" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>Team_SD-score</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost_type">
      <value value="&quot;linear&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="&quot;Off&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_0Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_0Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_0Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_0Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_0Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_0Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_0PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K10_0PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K10_0PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_RT5_K0_0PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K10_0PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_HW5_K0_0PSelf_noise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_100RT5_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_100RT5_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_100N_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_100N_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_HW5_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_0Cnoise" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2021_N_K0_20Cnoise" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_HW5_K10_20PSelf" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K10_45PSelf" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K10_50PSelf" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K10_25PSelf" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_HW5_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_N_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_N_K0_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_N_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_HW5_K0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_HW5_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_HW5_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_N_K10_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_N_K10_20Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_N_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_HW5_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_RT5_K10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2022_HW5_K0_50Cnoise" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Hamming" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXX_Random_NetworkXXXXXXXXXXX" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>sol_list_test</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_R5_K10_20CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_N_K10_20CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K10_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_N5_K0_20CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K0_20CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_R5_K0_20CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K0_20CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K10_50CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K0_50CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_R5_K10_50CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_R5_K0_50CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_N_K10_50CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K10_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_N_K0_50CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K0_50CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_N_K10_0CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_N_K0_0CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_R5_K10_0CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_R5_K0_0CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_H5_K10_0CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K10_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND_H5_K0_0CNXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K0_0CN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_R5_K10_20PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_R5_K0_20PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_R5_K0_50PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_R5_K10_50PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K10_50PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K0_50PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K0_20PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K10_20PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_N_K10_20PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K10_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_N_K0_20PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K0_20PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_N_K0_50PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K0_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_N_K10_50PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K10_50PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_R5_K10_PS_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_5PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_0PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_10PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_15PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_20PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_25PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_30PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_35PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_40PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_45PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_50PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_R5_K0_PS_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_0PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_5PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_10PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_15PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_20PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_25PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_30PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_35PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_40PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_45PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_50PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_H5_K10_PS_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_0PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_5PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_10PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_15PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_20PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_25PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_30PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_35PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_40PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_45PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_50PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_H5_K0_PS_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_0PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_5PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_10PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_15PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_20PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_25PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_30PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_35PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_40PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_45PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_50PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_N_K10_PS_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_0PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_5PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_10PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_15PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_20PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_25PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_30PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_35PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_40PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_45PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_50PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_N_K0_PS_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_0PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_5PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_10PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_15PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_20PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_25PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_30PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_35PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_40PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_45PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_50PS_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_R5_K10_PS_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_0PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_5PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_10PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_15PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_20PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_25PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_30PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_35PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_40PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_45PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_50PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_R5_K0_5PS_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_0PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_5PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_10PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_15PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_20PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_25PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_30PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_35PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_40PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_45PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_50PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_H5_K10_5PS_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_0PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_5PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_10PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_15PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_20PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_25PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_30PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_35PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_40PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_45PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_50PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_H5_K0_5PS_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_0PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_5PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_10PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_15PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_20PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_25PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_30PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_35PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_40PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_45PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_50PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_N_K10_5PS_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_0PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_5PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_10PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_15PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_20PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_25PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_30PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_35PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_40PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_45PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_50PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_N_K0_5PS_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_0PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_5PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_10PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_15PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_20PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_25PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_30PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_35PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_40PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_45PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_50PS_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_R5_K10_CN_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_5CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_10CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_15CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_20CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_25CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_30CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_35CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_40CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_45CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_50CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_R5_K0_CN_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_5CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_10CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_15CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_20CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_25CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_30CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_35CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_40CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_45CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_50CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_H5_K10_CN_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_5CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_10CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_15CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_20CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_25CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_30CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_35CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_40CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_45CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_50CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_H5_K0_CN_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_5CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_10CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_15CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_20CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_25CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_30CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_35CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_40CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_45CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_50CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_N_K10_CN_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_5CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_10CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_15CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_20CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_25CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_30CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_35CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_40CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_45CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_50CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_N_K0_CN_LN___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_5CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_10CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_15CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_20CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_25CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_30CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_35CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_40CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_45CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_50CN_LN" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_R5_K10_CN_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_5CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_10CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_15CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_20CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_25CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_30CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_35CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_40CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_45CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K10_50CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_R5_K0_CN_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_5CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_10CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_15CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_20CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_25CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_30CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_35CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_40CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_45CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R5_K0_50CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_H5_K10_CN_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_5CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_10CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_15CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_20CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_25CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_30CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_35CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_40CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_45CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K10_50CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_H5_K0_CN_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_5CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_10CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_15CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_20CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_25CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_30CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_35CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_40CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_45CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="H5_K0_50CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_N_K10_CN_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_5CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_10CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_15CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_20CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_25CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_30CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_35CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_40CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_45CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K10_50CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXXXXXX_N_K0_CN_FC___" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;lattice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;Self&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Perception_Superiority_level">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_5CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_10CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_15CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_20CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_25CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_30CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_35CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_40CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_45CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N_K0_50CN_FC" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;fully_connected_network&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_R5_K10_0PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_R5_K0_0PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_R5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Risk_taker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="risk_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K0_0PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_H5_K10_0PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_H5_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_N_K10_0PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K10_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="XXXXXXXXRND9_N_K0_0PSXXXXXXXXX" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;hard_worker&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exploring_dimension">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Copy_error">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND1_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND2_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND3_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="148"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND4_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="198"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND5_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="247"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND6_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="297"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND7_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="346"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND8_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="396"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND9_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="445"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND10_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="495"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND20_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="990"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND30_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1485"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND40_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="1980"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND50_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2475"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND60_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="2970"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND70_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3465"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND80_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="3960"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND90_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4455"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RND100_N_K0_0PS" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-score</metric>
    <metric>number-of-unique-solutions</metric>
    <metric>cost</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <enumeratedValueSet variable="number-of-agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_type">
      <value value="&quot;Normal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enable-space-analysis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Network_type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree">
      <value value="4940"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mix_team">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c_error">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Superior_Perception">
      <value value="&quot;None&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
